@@ -48,7 +48,6 @@ class Client(Buildin):
         self._auth = None
         self._pool = None
         self._protocol = None
-        self._pid = 0
         self._write_pkg = self._ensure_write if auto_reconnect else self._write
         self._reconnect = auto_reconnect
         self._scope = '@t'  # default to thingsdb scope
@@ -562,7 +561,7 @@ class Client(Buildin):
             try:
                 room = self._rooms[room_id]
             except KeyError:
-                logging.warn(
+                logging.warning(
                     f'Got an event (tp:{pkg.tp}) for room Id {room_id} but '
                     f'the room is not known by the ThingsDB client')
             else:
@@ -586,11 +585,12 @@ class Client(Buildin):
         except KeyError:
             if pkg.tp == Proto.ON_WARN:
                 warn = pkg.data
-                logging.warn(
+                logging.warning(
                     f'ThingsDB: '
                     f'{warn["warn_msg"]} ({warn["warn_code"]})')
             else:
-                logging.warn(f'Unexpected event: tp:{pkg.tp} data:{pkg.data}')
+                logging.warning(
+                    f'Unexpected event: tp:{pkg.tp} data:{pkg.data}')
         else:
             asyncio.ensure_future(self._on_room(room_id, pkg), loop=self._loop)
 
